==> haskell-vty-unix-0.1.0.0-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vty-unix.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vty-unix
version:              0.1.0.0
visibility:           public
id:                   vty-unix-0.1.0.0-8L9z1F4tSQ5HQr7JiGapzn
key:                  vty-unix-0.1.0.0-8L9z1F4tSQ5HQr7JiGapzn
license:              BSD-3-Clause
copyright:            (c) 2023 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty
synopsis:             Unix backend for Vty
description:          This package provides Unix terminal support for Vty.
category:             User Interfaces
abi:                  a8db1c49eb39ee23a00b962e8d920048
exposed:              True
exposed-modules:
    Data.Terminfo.Eval Data.Terminfo.Parse Graphics.Vty.Platform.Unix
    Graphics.Vty.Platform.Unix.Input
    Graphics.Vty.Platform.Unix.Input.Classify
    Graphics.Vty.Platform.Unix.Input.Classify.Parse
    Graphics.Vty.Platform.Unix.Input.Classify.Types
    Graphics.Vty.Platform.Unix.Input.Focus
    Graphics.Vty.Platform.Unix.Input.Loop
    Graphics.Vty.Platform.Unix.Input.Mouse
    Graphics.Vty.Platform.Unix.Input.Paste
    Graphics.Vty.Platform.Unix.Input.Terminfo
    Graphics.Vty.Platform.Unix.Input.Terminfo.ANSIVT
    Graphics.Vty.Platform.Unix.Output
    Graphics.Vty.Platform.Unix.Output.Color
    Graphics.Vty.Platform.Unix.Output.TerminfoBased
    Graphics.Vty.Platform.Unix.Output.XTermColor
    Graphics.Vty.Platform.Unix.Settings

import-dirs:          /usr/lib/ghc-9.2.8/site-local/vty-unix-0.1.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/vty-unix-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vty-unix
hs-libraries:         HSvty-unix-0.1.0.0-8L9z1F4tSQ5HQr7JiGapzn
includes:             cbits/gwinsz.h
depends:
    base-4.16.4.0 blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK
    bytestring-0.11.4.0 containers-0.6.5.1 deepseq-1.4.6.1
    microlens-0.4.13.1-HPplyG5VOciEIF62YegSgA
    microlens-mtl-0.2.0.3-K2j2D46quth4CyQpetHsMp
    microlens-th-0.4.3.15-HCvCCXssdEL7TtTaXAE5ex mtl-2.2.2
    parsec-3.1.15.0 stm-2.5.0.2 terminfo-0.4.1.5 transformers-0.5.6.2
    unix-2.7.2.2 utf8-string-1.0.2-AaPuiI83MyhDGzjGdO2RZO
    vector-0.13.1.0-1cpgbj3eXUqGZ3uVszXgJ9
    vty-6.0-3x3BRk3TcsS1lgb76ILioc

haddock-interfaces:   /usr/share/doc/haskell-vty-unix/html/vty-unix.haddock
haddock-html:         /usr/share/doc/haskell-vty-unix/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vty-unix-0.2.0.0-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vty-unix.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vty-unix
version:              0.2.0.0
visibility:           public
id:                   vty-unix-0.2.0.0-CQyWds7gToX75VthKFA0Bs
key:                  vty-unix-0.2.0.0-CQyWds7gToX75VthKFA0Bs
license:              BSD-3-Clause
copyright:            (c) 2023 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty
synopsis:             Unix backend for Vty
description:          This package provides Unix terminal support for Vty.
category:             User Interfaces
abi:                  5b4404dba6232e3948502bf4654ae2ff
exposed:              True
exposed-modules:
    Data.Terminfo.Eval Data.Terminfo.Parse Graphics.Vty.Platform.Unix
    Graphics.Vty.Platform.Unix.Input
    Graphics.Vty.Platform.Unix.Input.Classify
    Graphics.Vty.Platform.Unix.Input.Classify.Parse
    Graphics.Vty.Platform.Unix.Input.Classify.Types
    Graphics.Vty.Platform.Unix.Input.Focus
    Graphics.Vty.Platform.Unix.Input.Loop
    Graphics.Vty.Platform.Unix.Input.Mouse
    Graphics.Vty.Platform.Unix.Input.Paste
    Graphics.Vty.Platform.Unix.Input.Terminfo
    Graphics.Vty.Platform.Unix.Input.Terminfo.ANSIVT
    Graphics.Vty.Platform.Unix.Output
    Graphics.Vty.Platform.Unix.Output.Color
    Graphics.Vty.Platform.Unix.Output.TerminfoBased
    Graphics.Vty.Platform.Unix.Output.XTermColor
    Graphics.Vty.Platform.Unix.Settings

import-dirs:          /usr/lib/ghc-9.2.8/site-local/vty-unix-0.2.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/vty-unix-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vty-unix
hs-libraries:         HSvty-unix-0.2.0.0-CQyWds7gToX75VthKFA0Bs
includes:             cbits/gwinsz.h
depends:
    base-4.16.4.0 blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK
    bytestring-0.11.4.0 containers-0.6.5.1 deepseq-1.4.6.1
    microlens-0.4.13.1-HPplyG5VOciEIF62YegSgA
    microlens-mtl-0.2.0.3-K2j2D46quth4CyQpetHsMp
    microlens-th-0.4.3.16-8dAPUb0xcemJkOKNZxCZbE mtl-2.2.2
    parsec-3.1.15.0 stm-2.5.0.2 terminfo-0.4.1.5 transformers-0.5.6.2
    unix-2.7.2.2 utf8-string-1.0.2-AaPuiI83MyhDGzjGdO2RZO
    vector-0.13.1.0-1cpgbj3eXUqGZ3uVszXgJ9
    vty-6.1-MtabYugDIe7PoW1M9CLMS

haddock-interfaces:   /usr/share/doc/haskell-vty-unix/html/vty-unix.haddock
haddock-html:         /usr/share/doc/haskell-vty-unix/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
